#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['django_template_breakpoint', 'django_template_breakpoint.templatetags']

package_data = \
{'': ['*']}

install_requires = \
['django']

extras_require = \
{'test': ['pytest']}

setup(name='django_template_breakpoint',
      version='0.0.1',
      description='A template tag for dropping into a debugger inside a Django template.',
      author=None,
      author_email='Peter Inglesby <peter.inglesby@gmail.com>',
      url=None,
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      extras_require=extras_require,
      python_requires='>=3.7',
     )
